summaryrefslogtreecommitdiff
path: root/tests/backends
diff options
context:
space:
mode:
authorSimon Charette <charette.s@gmail.com>2015-04-17 17:38:20 -0400
committerSimon Charette <charette.s@gmail.com>2015-05-20 13:46:13 -0400
commitbe67400b477c1b0e7e81766f41bbceed0de74bdc (patch)
treefd8e6d087082754df9159a5549bfa80e2a8c57d9 /tests/backends
parente2b77aceddbda9071fcfc38f90fb50d091d0b5fc (diff)
Refs #24652 -- Used SimpleTestCase where appropriate.
Diffstat (limited to 'tests/backends')
-rw-r--r--tests/backends/tests.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/backends/tests.py b/tests/backends/tests.py
index 0773c9fd64..f5ec488c86 100644
--- a/tests/backends/tests.py
+++ b/tests/backends/tests.py
@@ -25,8 +25,8 @@ from django.db.models import Avg, StdDev, Sum, Variance
from django.db.models.sql.constants import CURSOR
from django.db.utils import ConnectionHandler
from django.test import (
- TestCase, TransactionTestCase, mock, override_settings, skipIfDBFeature,
- skipUnlessDBFeature,
+ SimpleTestCase, TestCase, TransactionTestCase, mock, override_settings,
+ skipIfDBFeature, skipUnlessDBFeature,
)
from django.test.utils import str_prefix
from django.utils import six
@@ -35,7 +35,7 @@ from django.utils.six.moves import range
from . import models
-class DummyBackendTest(TestCase):
+class DummyBackendTest(SimpleTestCase):
def test_no_databases(self):
"""
@@ -1096,7 +1096,7 @@ class DBConstraintTestCase(TestCase):
self.assertEqual(intermediary_model.objects.count(), 2)
-class BackendUtilTests(TestCase):
+class BackendUtilTests(SimpleTestCase):
def test_format_number(self):
"""